@@ -6,7 +6,7 @@ from algora.common.decorators import data_request
 from algora.common.requests import __get_request
 
 
-@data_request(transformer=_transform_fred_observations)
+@data_request(transformers=[_transform_fred_observations])
 def get_series(query: FredQuery) -> DataFrame:
     """
     Get FRED series.
