@@ -1,4 +1,5 @@
 import pandas as pd
+from algora.common.function import data_required_transform
 from requests import Response
 
 from algora.api.data.query.__util import (
@@ -7,7 +8,6 @@ from algora.api.data.query.__util import (
     _query_timeseries_request_info,
 )
 from algora.api.data.query.model import TimeseriesQueryRequest
-from algora.common.decorators import data_request
 from algora.common.requests import __async_post_request, __async_get_request
 
 
@@ -42,7 +42,6 @@ async def async_query_dataset_csv(id: str, data=None) -> Response:
     return await __async_get_request(**request_info)
 
 
-@data_request
 def async_query_timeseries(request: TimeseriesQueryRequest) -> pd.DataFrame:
     """
     Asynchronously query timeseries dataset by timeseries query request.
