@@ -2,10 +2,11 @@
 Data classes for API requests.
 """
 from datetime import datetime
-from typing import List, Optional
+from typing import List, Optional, Dict
 
 from pydantic import Field
 
+from algora.api.service.datasets.v2.model import TimeseriesFilter
 from algora.common.base import Base
 from algora.common.enum import Order
 from algora.common.type import Datetime
@@ -22,5 +23,5 @@ class TimeseriesQueryRequest(Base):
     page: Optional[int] = Field(default=None)
     limit: Optional[int] = Field(default=None)
     fields: Optional[List[str]] = Field(default=None)
-    sort: Order = Field(default=Order.DESC)
-    where: Optional[List[dict]] = Field(default=None)
+    sort: Dict[str, Order] = Field(default=Order.DESC)
+    where: Optional[List[TimeseriesFilter]] = Field(default=None)
