@@ -7,8 +7,6 @@ from algora.api.data.query.__util import (
     _query_timeseries_request_info,
 )
 from algora.api.data.query.model import TimeseriesQueryRequest
-from algora.common.decorators import data_request
-from algora.common.function import data_required_transform
 from algora.common.requests import __post_request, __get_request
 
 
@@ -43,7 +41,6 @@ def query_dataset_csv(id: str, data=None) -> Response:
     return __get_request(**request_info)
 
 
-@data_request(transformers=[data_required_transform])
 def query_timeseries(request: TimeseriesQueryRequest) -> pd.DataFrame:
     """
     Query timeseries dataset by timeseries query request.
