@@ -2,7 +2,7 @@ from typing import Optional, List
 
 from pandas import DataFrame
 
-from algora.api.data.query import query_dataset
+from algora.api.data.query import query_dataset, query_timeseries
 from algora.api.data.sdr.__util import (
     _get_by_date_request_info,
     _get_distinct_in_field_request_info,
@@ -68,7 +68,7 @@ def commodity(data_filter: Optional[DataFilter] = None):
         DataFrame: DataFrame
     """
     request_info = _commodity_request_info(data_filter)
-    return query_dataset(**request_info)
+    return query_timeseries(**request_info)
 
 
 @data_request
