@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Union, Any, Optional
 
 from algora.common.base_enum import BaseEnum
 
@@ -14,6 +14,7 @@ class Type(BaseEnum):
     ALIAS = "ALIAS"
     REF = "REF"
     CUSTOM = "CUSTOM"
+    UNSUPPORTED = "UNSUPPORTED"
 
 
 class PythonTypes(BaseEnum):
@@ -24,10 +25,13 @@ class PythonTypes(BaseEnum):
     NONE = "NONE"
     LIST = "LIST"
     SET = "SET"
+    DICT = "DICT"
     UNION = "UNION"
+    OPTIONAL = "OPTIONAL"
+    UNKNOWN = "UNKNOWN"
 
     @classmethod
-    def from_primitive(cls, primitive):
+    def from_type(cls, origin: Any, sub_types: Optional[Any] = None):
         value_lookup = {
             bool: "BOOLEAN",
             int: "INTEGER",
@@ -38,6 +42,16 @@ class PythonTypes(BaseEnum):
             list: "LIST",
             set: "SET",
             Union: "UNION",
+            dict: "DICT",
         }
-        value = value_lookup[primitive]
+        value = value_lookup.get(origin, "UNKNOWN")
+        if value == "UNION":
+            value = cls.evaluate_union(origin, sub_types)
         return cls(value=value)
+
+    @classmethod
+    def evaluate_union(cls, origin: Any, sub_types: Optional[Any] = None):
+        if sub_types and type(None) in sub_types:
+            return "OPTIONAL"
+        else:
+            return "UNION"
