@@ -23,18 +23,22 @@ class ObjectMetadataRequest(Base):
     class_name: str
     module: str
     path: str
+    version: str
     type: MetadataType
     constructor_parameters: Dict[str, Parameter]
     parent_classes: Optional[Set[str]]
+    docs: Optional[str]
 
 
 class ObjectMetadataResponse(Base):
     class_name: str
     module: str
     path: str
+    version: str
     type: MetadataType
     constructor_parameters: Dict[str, Parameter]
     parent_classes: Optional[Set[str]]
+    docs: Optional[str]
     created_by: str
     created_at: int
     updated_by: Optional[str]
