@@ -47,7 +47,7 @@ class Base(ABC, BaseModel):
         Returns:
             dict: Serialized data class as dict
         """
-        return json.loads(self.json())
+        return json.loads(self.json(by_alias=True))
 
     def base64_encoded(self, exclude=None) -> bytes:
         """
