@@ -10,9 +10,9 @@ logger = logging.getLogger(__name__)
 
 
 def __process_response(
-        response: Response,
-        processor: Callable[[Response], Any],
-        transformers: List[Callable[[Any], Any]]
+    response: Response,
+    processor: Callable[[Response], Any],
+    transformers: List[Callable[[Any], Any]],
 ):
     if response.status_code != 200 | response.status_code != 201:
         error = ApiError(
