@@ -7,6 +7,21 @@ from algora.common.base_enum import BaseEnum
 class Order(BaseEnum):
     ASC = "ASC"
     DESC = "DESC"
+    UNKNOWN = "UNKNOWN"
+
+
+class SqlOperator(BaseEnum):
+    NOT_IN = "NOT_IN"
+    IN = "IN"
+    NOT_EQUAL = "NOT_EQUAL"
+    EQUAL = "EQUAL"
+    LIKE = "LIKE"
+    NOT_LIKE = "NOT_LIKE"
+    GTE = "GTE"
+    GT = "GT"
+    LTE = "LTE"
+    LT = "LT"
+    UNKNOWN = "UNKNOWN"
 
 
 class FieldType(BaseEnum):
