@@ -59,3 +59,12 @@ class InvalidRequest(CustomBaseException):
 
     def __init__(self, message: str):
         super().__init__(message)
+
+
+class InvalidClassDefinition(CustomBaseException):
+    """
+    Custom exception for classes that arent defined correctly.
+    """
+
+    def __init__(self, message: str):
+        super().__init__(message)
